@@ -77,10 +77,3 @@ setGeneric("calculateMDS", function(x, ...) standardGeneric("calculateMDS"))
 #' @export
 #' @rdname runNMF
 setGeneric("calculateNMF", function(x, ...) standardGeneric("calculateNMF"))
-
-#' @export
-#' @rdname runDiffusionMap
-setGeneric("calculateDiffusionMap", function(x, ...) {
-    .Deprecated()
-    standardGeneric("calculateDiffusionMap")
-})
